//
//
// hello.ftdi.44.echo.c
//
// 115200 baud FTDI character echo, with flash string
//
// set lfuse to 0x7E for 20 MHz xtal
//
// Neil Gershenfeld
// 12/8/10
//
// (c) Massachusetts Institute of Technology 2010
// Permission granted for experimental and personal use;
// license for commercial sale available from MIT.
//

#include <avr/io.h>
#include <util/delay.h>
#include <avr/pgmspace.h>

#define output(directions,pin) (directions |= pin) // set port direction for output
#define set(port,pin) (port |= pin) // set port pin
#define clear(port,pin) (port &= (~pin)) // clear port pin
#define pin_test(pins,pin) (pins & pin) // test for port pin
#define bit_test(byte,bit) (byte & (1 << bit)) // test for bit set
#define bit_delay_time 8.5 // bit delay for 115200 with overhead
#define bit_delay() _delay_us(bit_delay_time) // RS232 bit delay
#define half_bit_delay() _delay_us(bit_delay_time/2) // RS232 half bit delay
#define char_delay() _delay_ms(10) // char delay

//#define serial_port PORTA
//#define serial_direction DDRA
//#define serial_pins PINA
//#define serial_pin_in (1 << PA0)
//#define serial_pin_out (1 << PA1)

#define port_a PORTA
#define direction_a DDRA
#define direction_b DDRB
#define pin_led_left (1 << PA3)
#define pin_led_right (1 << PA2)
#define pin_swt_left (1 << PA7)
#define pin_swt_right (1 << PB2)


int main(void) {
  //
  // main
  //
  static int ledstate; //0:left 1:right
  static int pushed; //0:not 1:pushed
  ledstate = 0;
  pushed = 0;
  //
  // set clock divider to /1
  //
  CLKPR = (1 << CLKPCE);
  CLKPR = (0 << CLKPS3) | (0 << CLKPS2) | (0 << CLKPS1) | (0 << CLKPS0);
  //
  // initialize output pins
  //
  //set(serial_port, serial_pin_out);
  //set(port_a, pin_led_left);
  //set(port_a, pin_led_right);

  //output(serial_direction, serial_pin_out);
  output(direction_a, pin_led_left);
  output(direction_a, pin_led_right);
  //
  // main loop
  //
  while (1) {
    //check input
    if( pin_test(PINA, pin_swt_left) == 0){
      if(pushed == 0 && ledstate == 1){
	ledstate = 0;
	clear(port_a, pin_led_right);
	set(port_a, pin_led_left);
      }
      pushed = 1;
      }else if(pin_test(PINB, pin_swt_right)==0){
      if(pushed == 0 && ledstate == 0){
	ledstate = 1;
	clear(port_a, pin_led_left);
	set(port_a, pin_led_right);
      }
      pushed = 1;
    }else{
      pushed = 0;
    }
    
  }
}

